﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Telerik.Web.UI;
using System.Web.UI;
using System.Text;
/// <summary>
/// Utility class that allows auto-sized dialogs of radalert, radconfirm and radprompt to be opened from server-side in ajax and non-ajax scenarios
/// </summary>
public class AutoSizedStandardDialogs
{

    #region Constructor
    public AutoSizedStandardDialogs()
    {
    }
    #endregion

    #region RadAlert Methods
    /// <summary>
    /// Opens auto-sized radalert from server-side when a non-ajax postback is made or when page is loading for first time
    /// </summary>
    /// <param name="key"></param>
    /// <param name="page"></param>
    /// <param name="text"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="title"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="imgUrl"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    public static void RadAlertAutoSized(string text, int? width, int? height, string title, string callBackFnName, string imgUrl, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        Page page = HttpContext.Current.Handler as Page;
        string key = Guid.NewGuid().ToString();
        ClientScriptManager clientScript = page.ClientScript;
        if (!clientScript.IsStartupScriptRegistered(key))
        {
            string script = String.Format("Sys.Application.add_load( showAlert); function showAlert() {{ {0} radalert('{1}',{2},{3},{4},{5},{6},{7}, maxSizeArray,{8} );  Sys.Application.remove_load( showAlert);}}", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), title == null ? "null" : "'" + title + "'", callBackFnName == null ? "null" : callBackFnName, imgUrl == null ? "null" : "'" + imgUrl + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));
            clientScript.RegisterStartupScript(page.GetType(), key, script, true);
        }
    }
    /// <summary>
    /// Gets the JavaScript to inject when opening auto-sized radalert from server-side in non-ajax sceanrios. This can be injected into the page using ClientScript.RegisterStartupScript.
    /// </summary>
    /// <param name="key"></param>
    /// <param name="page"></param>
    /// <param name="text"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="title"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="imgUrl"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    /// <returns></returns>
    public static string RadAlertAutoSizedScript(string text, int? width, int? height, string title, string callBackFnName, string imgUrl, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {

        return String.Format("Sys.Application.add_load( showAlert); function showAlert() {{ {0} radalert('{1}',{2},{3},{4},{5},{6},{7}, maxSizeArray,{8} ); Sys.Application.remove_load( showAlert);}}", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), title == null ? "null" : "'" + title + "'", callBackFnName == null ? "null" : callBackFnName, imgUrl == null ? "null" : "'" + imgUrl + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));

    }
    /// <summary>
    /// Gets the JavaScript to inject when opening auto-sized radalert from server-side in ajax scenarios. This can be injected into the page using ResponseScripts.Add or any other appropriate method.
    /// It's not necessary to have RadAjaxManager when using this method.
    /// </summary>
    /// <param name="key"></param>
    /// <param name="page"></param>
    /// <param name="text"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="title"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="imgUrl"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    /// <returns></returns>
    public static string RadAlertAutoSizedScriptFromAjax(string text, int? width, int? height, string title, string callBackFnName, string imgUrl, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {

        return String.Format("{0} radalert('{1}',{2},{3},{4},{5},{6},{7}, maxSizeArray, {8} );", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), title == null ? "null" : "'" + title + "'", callBackFnName == null ? "null" : callBackFnName, imgUrl == null ? "null" : "'" + imgUrl + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));

    }
    /// <summary>
    /// Opens auto-sized radalert from server-side when an ajax postback is made using RadAjaxManager
    /// </summary>
    /// <param name="ajaxManager"></param>
    /// <param name="text"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="title"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="imgUrl"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    public static void RadAlertAutoSizedFromAjax(string text, int? width, int? height, string title, string callBackFnName, string imgUrl, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        Page page = HttpContext.Current.Handler as Page;
        string script = String.Format(" {0} radalert('{1}',{2},{3},{4},{5},{6},{7}, maxSizeArray, {8} );", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), title == null ? "null" : "'" + title + "'", callBackFnName == null ? "null" : callBackFnName, imgUrl == null ? "null" : "'" + imgUrl + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));
        RadAjaxManager.GetCurrent(page).ResponseScripts.Add(script);
    }

    #endregion RadAlert Methods

    #region RadConfirm Methods
    /// <summary>
    /// Opens auto-sized radconfirm from server-side when a non-ajax postback is made or when page is loading for first time
    /// </summary>
    /// <param name="key"></param>
    /// <param name="page"></param>
    /// <param name="text"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="callerObject"></param>
    /// <param name="title"></param>
    /// <param name="imgUrl"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    public static void RadConfirmAutoSized(string text, string callBackFnName, int? width, int? height, object callerObject, string title, string imgUrl, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        Page page = HttpContext.Current.Handler as Page;
        string key = Guid.NewGuid().ToString();
        ClientScriptManager clientScript = page.ClientScript;
        if (!clientScript.IsStartupScriptRegistered(key))
        {
            string jsonString = null;
            if (callerObject != null)
            {
                var javaScriptSerializer = new System.Web.Script.Serialization.JavaScriptSerializer();
                jsonString = javaScriptSerializer.Serialize(callerObject);
            }
            string script = String.Format("Sys.Application.add_load( showConfirm); function showConfirm () {{ {0} radconfirm('{1}',{2},{3},{4},{5},{6},{7},{8}, maxSizeArray,{9} );  Sys.Application.remove_load( showConfirm);}}", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), callBackFnName == null ? "null" : callBackFnName, width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), jsonString == null ? "null" : jsonString, title == null ? "null" : "'" + title + "'", imgUrl == null ? "null" : "'" + imgUrl + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));
            clientScript.RegisterStartupScript(page.GetType(), key, script, true);
        }
    }
    /// <summary>
    /// Gets the JavaScript to inject when opening auto-sized radconfirm from server-side in non-ajax scenarios.  This can be injected into the page using ClientScript.RegisterStartupScript.
    /// </summary>
    /// <param name="key"></param>
    /// <param name="page"></param>
    /// <param name="text"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="callerObject"></param>
    /// <param name="title"></param>
    /// <param name="imgUrl"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    /// <returns></returns>
    public static string RadConfirmAutoSizedScript(string text, string callBackFnName, int? width, int? height, object callerObject, string title, string imgUrl, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        var javaScriptSerializer = new System.Web.Script.Serialization.JavaScriptSerializer();
        string jsonString = javaScriptSerializer.Serialize(callerObject);
        return String.Format("Sys.Application.add_load( showConfirm); function showConfirm () {{ {0} radconfirm('{1}',{2},{3},{4},{5},{6},{7},{8}, maxSizeArray,{9} ); Sys.Application.remove_load( showConfirm);}}", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), callBackFnName == null ? "null" : callBackFnName, width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), jsonString == null ? "null" : jsonString, title == null ? "null" : "'" + title + "'", imgUrl == null ? "null" : "'" + imgUrl + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));
    }
    /// <summary>
    /// Gets the JavaScript to inject when opening auto-sized radconfirm from server-side in ajax scenarios.  This can be injected into the page using ResponseScripts.Add or any other appropriate method.
    /// It's not necessary to have RadAjaxManager when using this method.
    /// </summary>
    /// <param name="key"></param>
    /// <param name="page"></param>
    /// <param name="text"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="callerObject"></param>
    /// <param name="title"></param>
    /// <param name="imgUrl"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    /// <returns></returns>
    public static string RadConfirmAutoSizedScriptFromAjax(string text, string callBackFnName, int? width, int? height, object callerObject, string title, string imgUrl, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        var javaScriptSerializer = new System.Web.Script.Serialization.JavaScriptSerializer();
        string jsonString = javaScriptSerializer.Serialize(callerObject);
        return String.Format("Sys.Application.add_load( showConfirm); function showConfirm () {{ {0} radconfirm('{1}',{2},{3},{4},{5},{6},{7},{8}, maxSizeArray,{9} ); Sys.Application.remove_load( showConfirm);}}", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), callBackFnName == null ? "null" : callBackFnName, width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), jsonString == null ? "null" : jsonString, title == null ? "null" : "'" + title + "'", imgUrl == null ? "null" : "'" + imgUrl + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));
    }
    /// <summary>
    /// Opens auto-sized radconfirm from server-side when an ajax postback is made using RadAjaxManager
    /// </summary>
    /// <param name="ajaxManager"></param>
    /// <param name="text"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="callerObject"></param>
    /// <param name="title"></param>
    /// <param name="imgUrl"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    public static void RadConfirmAutoSizedFromAjax(string text, string callBackFnName, int? width, int? height, object callerObject, string title, string imgUrl, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        Page page = HttpContext.Current.Handler as Page;
        var javaScriptSerializer = new System.Web.Script.Serialization.JavaScriptSerializer();
        string jsonString = javaScriptSerializer.Serialize(callerObject);
        string script = String.Format("{0} radconfirm('{1}',{2},{3},{4},{5},{6},{7},{8}, maxSizeArray,{9} );", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), callBackFnName == null ? "null" : callBackFnName, width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), jsonString == null ? "null" : jsonString, title == null ? "null" : "'" + title + "'", imgUrl == null ? "null" : "'" + imgUrl + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));
        RadAjaxManager.GetCurrent(page).ResponseScripts.Add(script);
    }

    #endregion

    #region RadPrompt Methods
    /// <summary>
    /// Opens auto-sized radprompt from server-side when a non-ajax postback is made or when page is loading for first time
    /// </summary>
    /// <param name="key"></param>
    /// <param name="page"></param>
    /// <param name="text"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="callerObject"></param>
    /// <param name="title"></param>
    /// <param name="initialValue"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    public static void RadPromptAutoSized(string text, string callBackFnName, int? width, int? height, object callerObject, string title, string initialValue, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        Page page = HttpContext.Current.Handler as Page;
        string key = Guid.NewGuid().ToString();
        ClientScriptManager clientScript = page.ClientScript;
        if (!clientScript.IsStartupScriptRegistered(key))
        {
            string jsonString = null;
            if (callerObject != null)
            {
                var javaScriptSerializer = new System.Web.Script.Serialization.JavaScriptSerializer();
                jsonString = javaScriptSerializer.Serialize(callerObject);
            }
            string script = String.Format("Sys.Application.add_load( showPrompt); function showPrompt () {{ {0} radprompt('{1}',{2},{3},{4},{5},{6},{7},{8}, maxSizeArray,{9} ); Sys.Application.remove_load( showPrompt);}}", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), callBackFnName == null ? "null" : callBackFnName, width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), jsonString == null ? "null" : jsonString, title == null ? "null" : "'" + title + "'", initialValue == null ? "null" : "'" + initialValue + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));
            clientScript.RegisterStartupScript(page.GetType(), key, script, true);
        }
    }
    /// <summary>
    /// Gets the JavaScript to inject when opening auto-sized radprompt from server-side in non-ajax sceanrios. This can be injected into the page using ClientScript.RegisterStartupScript.
    /// </summary>
    /// <param name="key"></param>
    /// <param name="page"></param>
    /// <param name="text"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="callerObject"></param>
    /// <param name="title"></param>
    /// <param name="initialValue"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    /// <returns></returns>
    public static string RadPromptAutoSizedScript(string text, string callBackFnName, int? width, int? height, object callerObject, string title, string initialValue, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        var javaScriptSerializer = new System.Web.Script.Serialization.JavaScriptSerializer();
        string jsonString = javaScriptSerializer.Serialize(callerObject);
        return String.Format("Sys.Application.add_load( showPrompt); function showPrompt () {{ {0} radprompt('{1}',{2},{3},{4},{5},{6},{7},{8}, maxSizeArray, {9} ); Sys.Application.remove_load( showPrompt);}}", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), callBackFnName == null ? "null" : callBackFnName, width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), jsonString == null ? "null" : jsonString, title == null ? "null" : "'" + title + "'", initialValue == null ? "null" : "'" + initialValue + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));
    }
    /// <summary>
    /// Gets the JavaScript to inject when opening auto-sized radprompt from server-side in ajax scenarios. This can be injected into the page using ResponseScripts.Add or any other appropriate method.
    /// It's not necessary to have RadAjaxManager when using this method.   
    /// </summary>
    /// <param name="key"></param>
    /// <param name="page"></param>
    /// <param name="text"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="callerObject"></param>
    /// <param name="title"></param>
    /// <param name="initialValue"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    /// <returns></returns>
    public static string RadPromptAutoSizedScriptFromAjax(string text, string callBackFnName, int? width, int? height, object callerObject, string title, string initialValue, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        var javaScriptSerializer = new System.Web.Script.Serialization.JavaScriptSerializer();
        string jsonString = javaScriptSerializer.Serialize(callerObject);
        return String.Format("Sys.Application.add_load( showPrompt); function showPrompt () {{ {0} radprompt('{1}',{2},{3},{4},{5},{6},{7},{8}, maxSizeArray,{9} ); Sys.Application.remove_load( showPrompt);}}", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), callBackFnName == null ? "null" : callBackFnName, width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), jsonString == null ? "null" : jsonString, title == null ? "null" : "'" + title + "'", initialValue == null ? "null" : "'" + initialValue + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));
    }
    /// <summary>
    /// Opens auto-sized radprompt from server-side when an ajax postback is made using RadAjaxManager
    /// </summary>
    /// <param name="ajaxManager"></param>
    /// <param name="text"></param>
    /// <param name="callBackFnName"></param>
    /// <param name="width"></param>
    /// <param name="height"></param>
    /// <param name="callerObject"></param>
    /// <param name="title"></param>
    /// <param name="initialValue"></param>
    /// <param name="isSizeFixed"></param>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    public static void RadPromptAutoSizedFromAjax(string text, string callBackFnName, int? width, int? height, object callerObject, string title, string initialValue, bool isSizeFixed = false, int maxWidthFactorInPercent = 90, int maxHeightFactorInPercent = 90, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        Page page = HttpContext.Current.Handler as Page;
        var javaScriptSerializer = new System.Web.Script.Serialization.JavaScriptSerializer();
        string jsonString = javaScriptSerializer.Serialize(callerObject);
        string script = String.Format("{0} radprompt('{1}',{2},{3},{4},{5},{6},{7},{8}, maxSizeArray, {9} );", GetMaxArrayScript(maxWidthFactorInPercent, maxHeightFactorInPercent), CleanText(text), callBackFnName == null ? "null" : callBackFnName, width == null ? "null" : width.Value.ToString(), height == null ? "null" : height.Value.ToString(), jsonString == null ? "null" : jsonString, title == null ? "null" : "'" + title + "'", initialValue == null ? "null" : "'" + initialValue + "'", isSizeFixed.ToString().ToLower(), GetDialogOptionsInJSON(dialogOptions));
        RadAjaxManager.GetCurrent(page).ResponseScripts.Add(script);
    }

    #endregion

    #region RadWindow Methods
    /// <summary>
    /// Opens an animated radwindow from server-side when a non-ajax postback is made or when page is loading for first time.
    /// This tries to auto-size the radwindow using the client-side api of autosize( ).
    /// </summary>
    /// <param name="radWindow"></param>
    /// <param name="dialogOptions"></param>
    public static void RadWindowAutoSized(RadWindow radWindow, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        Page page = HttpContext.Current.Handler as Page;
        string key = Guid.NewGuid().ToString();
        ClientScriptManager clientScript = page.ClientScript;
        if (!clientScript.IsStartupScriptRegistered(key))
        {
            string script = String.Format("Sys.Application.add_load( showRadWindow); function showRadWindow() {{ var wd = $find('{0}'); az.showAnimatedRadWindow(wd,{1}); Sys.Application.remove_load( showRadWindow);}}", radWindow.ClientID, GetDialogOptionsInJSON(dialogOptions));
            clientScript.RegisterStartupScript(page.GetType(), key, script, true);
        }
    }

    /// <summary>
    /// Opens an animated radwindow from server-side when an ajax postback is made using RadAjaxManager.
    /// This tries to auto-size the radwindow using the client-side api of autosize( ).
    /// </summary>
    /// <param name="radWindow"></param>
    /// <param name="dialogOptions"></param>
    public static void RadWindowAutoSizedFromAjax(RadWindow radWindow, AutoSizedStandardDialogOptions dialogOptions = null)
    {
        Page page = HttpContext.Current.Handler as Page;
        string script = String.Format("var wd = $find('{0}'); az.showAnimatedRadWindow(wd,{1});", radWindow.ClientID, GetDialogOptionsInJSON(dialogOptions));
        RadAjaxManager.GetCurrent(page).ResponseScripts.Add(script);
    }
    #endregion RadWindow Methods

    #region Other Methods
    /// <summary>
    /// Gets the JavaScript for generating the max size factor array. This is an extra parameter that is passed to auto-sized standard dialogs.
    /// </summary>
    /// <param name="maxWidthFactorInPercent"></param>
    /// <param name="maxHeightFactorInPercent"></param>
    /// <returns></returns>
    private static string GetMaxArrayScript(int maxWidthFactorInPercent, int maxHeightFactorInPercent)
    {
        if (maxWidthFactorInPercent <= 0)
        {
            maxWidthFactorInPercent = 90;
        }
        else if (maxWidthFactorInPercent > 100)
        {
            maxWidthFactorInPercent = 100;
        }
        if (maxHeightFactorInPercent <= 0)
        {
            maxHeightFactorInPercent = 90;
        }
        else if (maxHeightFactorInPercent > 100)
        {
            maxHeightFactorInPercent = 100;
        }
        return String.Format("var maxSizeArray = new Array(); maxSizeArray.push({0}); maxSizeArray.push({1}); ", (float)(maxWidthFactorInPercent / 100.0), (float)(maxHeightFactorInPercent / 100.0));
    }


    /// <summary>
    /// Gets the JSON object for dialogOptions
    /// </summary>
    /// <param name="dialogOptions"></param>
    /// <returns></returns>
    private static string GetDialogOptionsInJSON(AutoSizedStandardDialogOptions dialogOptions)
    {
        StringBuilder optionsScript = null;
        if (dialogOptions != null)
        {
            optionsScript = new StringBuilder();
            optionsScript.Append("{");

            switch (dialogOptions.AnchorPosition)
            {
                case AnchorPosition.TopLeft:
                    optionsScript.Append("anchorPosition:'topLeft'");
                    break;
                case AnchorPosition.TopRight:
                    optionsScript.Append("anchorPosition:'topRight'");
                    break;
                case AnchorPosition.BottomLeft:
                    optionsScript.Append("anchorPosition:'bottomLeft'");
                    break;
                case AnchorPosition.BottomRight:
                    optionsScript.Append("anchorPosition:'bottomRight'");
                    break;
                case AnchorPosition.TopMiddle:
                    optionsScript.Append("anchorPosition:'topMiddle'");
                    break;
                case AnchorPosition.BottomMiddle:
                    optionsScript.Append("anchorPosition:'bottomMiddle'");
                    break;
                case AnchorPosition.LeftMiddle:
                    optionsScript.Append("anchorPosition:'leftMiddle'");
                    break;
                case AnchorPosition.RightMiddle:
                    optionsScript.Append("anchorPosition:'rightMiddle'");
                    break;
                case AnchorPosition.None:
                    optionsScript.Append("anchorPosition:null");
                    break;
            }
            if (dialogOptions.AnchorPosition == AnchorPosition.None)
            {
                if (dialogOptions.Left != null && dialogOptions.Left.Value >= 0)
                {
                    optionsScript.AppendFormat("{0}left:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.Left.Value);
                }
                if (dialogOptions.Top != null && dialogOptions.Top.Value >= 0)
                {
                    optionsScript.AppendFormat("{0}top:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.Top.Value);
                }
            }
            else
            {
                optionsScript.AppendFormat("{0}left:null,top:null", optionsScript.Length > 0 ? "," : string.Empty);
            }
            if (dialogOptions.AutoCloseDelay > 0)
            {
                optionsScript.AppendFormat("{0}autoCloseDelay:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.AutoCloseDelay);
            }
            if (dialogOptions.ClosejqAnimationDuration > 0)
            {
                optionsScript.AppendFormat("{0}closejqAnimationDuration:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.ClosejqAnimationDuration);
            }
            if (dialogOptions.ClosejqAnimation != ClosejqAnimation.None)
            {
                optionsScript.AppendFormat("{0}closejqAnimation:'{1}'", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.ClosejqAnimation.ToString().ToLower());
            }
            if (dialogOptions.ClosejqAnimation == ClosejqAnimation.None && !string.IsNullOrWhiteSpace(dialogOptions.ClosejqAnimationTargetCss))
            {
                dialogOptions.ClosejqAnimationTargetCss = dialogOptions.ClosejqAnimationTargetCss.Replace("\"", "'");
                dialogOptions.ClosejqAnimationTargetCss = dialogOptions.ClosejqAnimationTargetCss.Replace(@"""", "'");
                optionsScript.AppendFormat("{0}closejqAnimationTargetCss:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.ClosejqAnimationTargetCss);
            }

            if (dialogOptions.OpenjqAnimationDuration > 0)
            {
                optionsScript.AppendFormat("{0}openjqAnimationDuration:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.OpenjqAnimationDuration);
            }
            if (dialogOptions.OpenjqAnimation == OpenjqAnimation.None && !string.IsNullOrWhiteSpace(dialogOptions.OpenjqAnimationTargetCss))
            {
                dialogOptions.OpenjqAnimationTargetCss = dialogOptions.OpenjqAnimationTargetCss.Replace("\"", "'");
                dialogOptions.OpenjqAnimationTargetCss = dialogOptions.OpenjqAnimationTargetCss.Replace(@"""", "'");
                optionsScript.AppendFormat("{0}openjqAnimationTargetCss:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.OpenjqAnimationTargetCss);
            }
            else
            {
                optionsScript.AppendFormat("{0}openjqAnimationTargetCss:null", optionsScript.Length > 0 ? "," : string.Empty);
            }
            if (dialogOptions.OpenjqAnimation != OpenjqAnimation.None)
            {
                optionsScript.AppendFormat("{0}openjqAnimation:'{1}'", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.OpenjqAnimation.ToString().ToLower());
            }
            else
            {
                optionsScript.AppendFormat("{0}openjqAnimation:null", optionsScript.Length > 0 ? "," : string.Empty);
            }
            if (dialogOptions.ClosejqAnimation != ClosejqAnimation.None)
            {
                optionsScript.AppendFormat("{0}closejqAnimation:'{1}'", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.ClosejqAnimation.ToString().ToLower());
            }
            else
            {
                optionsScript.AppendFormat("{0}closejqAnimation:null", optionsScript.Length > 0 ? "," : string.Empty);
            }
            if (dialogOptions.ShowCountDown)
            {
                optionsScript.AppendFormat("{0}showCountDown:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.ShowCountDown.ToString().ToLower());
            }
            if (!string.IsNullOrWhiteSpace(dialogOptions.CountDownText))
            {
                optionsScript.AppendFormat("{0}countDownText:'{1}'", optionsScript.Length > 0 ? "," : string.Empty, AutoSizedStandardDialogs.CleanText(dialogOptions.CountDownText));
            }
            else
            {
                optionsScript.AppendFormat("{0}countDownText:null", optionsScript.Length > 0 ? "," : string.Empty);
            }
            if (!string.IsNullOrWhiteSpace(dialogOptions.CountDownClosingText))
            {
                optionsScript.AppendFormat("{0}countDownClosingText:'{1}'", optionsScript.Length > 0 ? "," : string.Empty, AutoSizedStandardDialogs.CleanText(dialogOptions.CountDownClosingText));
            }
            else
            {
                optionsScript.AppendFormat("{0}countDownClosingText:null", optionsScript.Length > 0 ? "," : string.Empty);
            }

            if (dialogOptions.CountDownInterval > 0)
            {
                optionsScript.AppendFormat("{0}countDownInterval:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.CountDownInterval);
            }

            if (!string.IsNullOrWhiteSpace(dialogOptions.jqOpenAnimateStartCallback))
            {
                optionsScript.AppendFormat("{0}jqOpenAnimateStartCallback:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.jqOpenAnimateStartCallback);
            }
            if (!string.IsNullOrWhiteSpace(dialogOptions.jqOpenAnimateEndCallback))
            {
                optionsScript.AppendFormat("{0}jqOpenAnimateEndCallback:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.jqOpenAnimateEndCallback);
            }


            optionsScript.AppendFormat("{0}jqUIAnimationEnabled:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.UIjqAnimationEnabled.ToString().ToLower());

            if (dialogOptions.OpenjqAnimationEasing != EasingjqAnimation.None)
            {
                optionsScript.AppendFormat("{0}openjqAnimationEasing:'{1}'", optionsScript.Length > 0 ? "," : string.Empty, ConvertFirstCharToLower(dialogOptions.OpenjqAnimationEasing.ToString()));
            }
            else
            {
                optionsScript.AppendFormat("{0}openjqAnimationEasing:'{1}'", optionsScript.Length > 0 ? "," : string.Empty, ConvertFirstCharToLower(EasingjqAnimation.Swing.ToString()));
            }
            if (dialogOptions.ClosejqAnimationEasing != EasingjqAnimation.None)
            {
                optionsScript.AppendFormat("{0}closejqAnimationEasing:'{1}'", optionsScript.Length > 0 ? "," : string.Empty, ConvertFirstCharToLower(dialogOptions.ClosejqAnimationEasing.ToString()));
            }
            else
            {
                optionsScript.AppendFormat("{0}closejqAnimationEasing:'{1}'", optionsScript.Length > 0 ? "," : string.Empty, ConvertFirstCharToLower(EasingjqAnimation.Swing.ToString()));
            }
            if (dialogOptions.HideOnClose)
            {
                optionsScript.AppendFormat("{0}hideOnClose:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.HideOnClose.ToString().ToLower());
            }
            if (dialogOptions.DoNotCloseInterval > 0)
            {
                optionsScript.AppendFormat("{0}donotCloseInterval:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.DoNotCloseInterval);
            }
            if (dialogOptions.ReshowInterval > 0)
            {
                optionsScript.AppendFormat("{0}reshowInterval:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.ReshowInterval);
            }

            optionsScript.AppendFormat("{0}isPositionFixed:{1}", optionsScript.Length > 0 ? "," : string.Empty, dialogOptions.IsPositionFixed.ToString().ToLower());

            optionsScript.Append("}");

        }

        return (optionsScript == null ? "{}" : optionsScript.ToString());
    }

    /// <summary>
    /// This cleans the text being passed to stanndard dialogs, so developer does not not need to bother about escaping single quotes and handling new line characters when opening these dialogs from server-side.
    /// </summary>
    /// <param name="text"></param>
    /// <returns></returns>
    public static string CleanText(string text)
    {
        if (text.IndexOf("'") >= 0)
        {
            text = text.Replace("'", "\\\'");
        }
        if (text.IndexOf("\r\n") >= 0)
        {
            text = text.Replace("\r\n", "<br />");
        } if (text.IndexOf("\n") >= 0)
        {
            text = text.Replace("\n", "<br />");
        }
        return text;
    }

    public static string ConvertFirstCharToLower(string s)
    {
        return char.ToLower(s[0]) + s.Substring(1);
    }
    #endregion

}
public enum AnchorPosition
{
    None = 0,
    TopLeft = 1,
    TopRight = 2,
    BottomLeft = 3,
    BottomRight = 4,
    TopMiddle = 5,
    BottomMiddle = 6,
    LeftMiddle = 7,
    RightMiddle = 8
}
public enum OpenjqAnimation
{
    None = 0,
    Fade = 1,
    SizeUp = 2,
    Slide = 3,
    Resize = 4,
    Blind = 5,
    Bounce = 6,
    Clip = 7,
    Drop = 8,
    Explode = 9,
    Fold = 10,
    Highlight = 11,
    Puff = 12,
    Pulsate = 13,
    Scale = 14,
    Shake = 15,
    Size = 17
}
public enum ClosejqAnimation
{
    None = 0,
    Fade = 1,
    SizeDown = 2,
    Slide = 3,
    Resize = 4,
    Blind = 5,
    Bounce = 6,
    Clip = 7,
    Drop = 8,
    Explode = 9,
    Fold = 10,
    Highlight = 11,
    Puff = 12,
    Pulsate = 13,
    Scale = 14,
    Shake = 15,
    Size = 17
}

public enum EasingjqAnimation
{
    None,
    Linear,
    Swing,
    EaseInQuad,
    EaseOutQuad,
    EaseInOutQuad,
    EaseInCubic,
    EaseOutCubic,
    EaseInOutCubic,
    EaseInQuart,
    EaseOutQuart,
    EaseInOutQuart,
    EaseInQuint,
    EaseOutQuint,
    EaseInOutQuint,
    EaseInExpo,
    EaseOutExpo,
    EaseInOutExpo,
    EaseInSine,
    EaseOutSine,
    EaseInOutSine,
    EaseInCirc,
    EaseOutCirc,
    EaseInOutCirc,
    EaseInElastic,
    EaseOutElastic,
    EaseInOutElastic,
    EaseInBack,
    EaseOutBack,
    EaseInOutBack,
    EaseInBounce,
    EaseOutBounce,
    EaseInOutBounce
}
public class AutoSizedStandardDialogOptions
{
    public AutoSizedStandardDialogOptions()
    {
    }
    public AnchorPosition AnchorPosition { get; set; }
    public int AutoCloseDelay { get; set; }
    public int ClosejqAnimationDuration { get; set; }
    public ClosejqAnimation ClosejqAnimation { get; set; }
    public string ClosejqAnimationTargetCss { get; set; }
    public int OpenjqAnimationDuration { get; set; }
    public OpenjqAnimation OpenjqAnimation { get; set; }
    public string OpenjqAnimationTargetCss { get; set; }
    public bool ShowCountDown { get; set; }
    public string CountDownText { get; set; }
    public string CountDownClosingText { get; set; }
    public int CountDownInterval { get; set; }
    public bool HideOnClose { get; set; }
    public int DoNotCloseInterval { get; set; }
    public int ReshowInterval { get; set; }
    public bool UIjqAnimationEnabled { get; set; }
    public string jqOpenAnimateStartCallback { get; set; }
    public string jqOpenAnimateEndCallback { get; set; }
    public string jqCloseAnimateStartCallback { get; set; }
    public string jqCloseAnimateEndCallback { get; set; }
    public EasingjqAnimation OpenjqAnimationEasing { get; set; }
    public EasingjqAnimation ClosejqAnimationEasing { get; set; }
    public int? Left { get; set; }
    public int? Top { get; set; }
    public int ScreenWidthForMaximizedView { get; set; }
    public int ScreenHeightForMaximizedView { get; set; }
    public int ScreenWidthForReducingLeftMargin { get; set; }
    public bool IsPositionFixed { get; set; }
}
